Class: ExampleFeatureTemplate
- Defined in:
- lib/generators/templates/cucumber/example_feature_template.rb
Instance Method Summary collapse
Methods inherited from Template
Constructor Details
This class inherits a constructor from Template
Instance Method Details
#body ⇒ Object
4 5 6 7 8 9 10 11 12 13 14 |
# File 'lib/generators/templates/cucumber/example_feature_template.rb', line 4 def body <<~EOF Feature: Login Page Scenario: A user can login Given I'm a registered user on the login page When I login with my credentials Then I can see the main page EOF end |